==> rdmo-0.14.0.tar.gz: rdmo-0.14.0/rdmo/projects/static/projects/js/project_questions/directives.js <==
angular.module('project_questions')

.directive('rangeInput', ['$timeout', function($timeout) {
    return {
        restrict: 'C',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModelController) {

            /* (val / 100.0) = (range_val - min) / (max - min) */

            if (attrs.minValue && attrs.maxValue) {
                ngModelController.$parsers.push(function(val) {
                    var min = parseFloat(attrs.minValue),
                        max = parseFloat(attrs.maxValue);

                    var value = 0.01 * parseFloat(val) * (max - min) + min;
                    return Math.round(value / attrs.step) * attrs.step;
                });

                ngModelController.$formatters.push(function(val) {
                    var min = parseFloat(attrs.minValue),
                        max = parseFloat(attrs.maxValue);

                    var value = 100.0 * (parseFloat(val) - min) / (max - min);
                    return value;
                });
            }
        }
    };
}])

.directive('dateInput', ['$timeout', function($timeout) {
    return {
        restrict: 'C',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModelController) {

            var lang = 'en',
                datepicker_format = 'yyyy-mm-dd',
                moment_format = 'YYYY-MM-DD';

            if (attrs.language === 'de') {
                lang = 'de';
                datepicker_format = 'dd.mm.yyyy';
                moment_format = 'DD.MM.YYYY';
            }

            ngModelController.$parsers.push(function(view_value) {
                if (view_value === '') {
                    return view_value;
                } else {
                    return moment(view_value, moment_format).format();
                }
            });

            ngModelController.$formatters.push(function(model_value) {
                if (model_value === '') {
                    return '';
                } else {
                    return moment(model_value).format(moment_format);
                }
            });

            $timeout(function() {
                $('.date').datepicker({
                    autoclose: true,
                    clearBtn: true,
                    orientation: 'bottom',
                    language: attrs.language,
                    format: datepicker_format
                });
                $('.date:focus').datepicker('show');
            });
        }
    };
}]);

==> rdmo-1.0.8.tar.gz: rdmo-1.0.8/rdmo/projects/static/projects/js/project_questions/directives.js <==
angular.module('project_questions')

.directive('rangeInput', ['$timeout', function($timeout) {
    return {
        restrict: 'C',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModelController) {

            /* (val / 100.0) = (range_val - min) / (max - min) */

            if (attrs.minValue && attrs.maxValue) {
                ngModelController.$parsers.push(function(val) {
                    var min = parseFloat(attrs.minValue),
                        max = parseFloat(attrs.maxValue);

                    var value = 0.01 * parseFloat(val) * (max - min) + min;
                    var d = 100 * attrs.step;
                    return Math.round(value * d) / d;
                });

                ngModelController.$formatters.push(function(val) {
                    var min = parseFloat(attrs.minValue),
                        max = parseFloat(attrs.maxValue);

                    var value = 100.0 * (parseFloat(val) - min) / (max - min);
                    return value;
                });
            }
        }
    };
}])

.directive('dateInput', ['$timeout', function($timeout) {
    return {
        restrict: 'C',
        require: 'ngModel',
        link: function(scope, element, attrs, ngModelController) {

            var lang = 'en',
                datepicker_format = 'yyyy-mm-dd',
                moment_format = 'YYYY-MM-DD';

            if (attrs.language === 'de') {
                lang = 'de';
                datepicker_format = 'dd.mm.yyyy';
                moment_format = 'DD.MM.YYYY';
            }

            ngModelController.$parsers.push(function(view_value) {
                if (view_value === '') {
                    return view_value;
                } else {
                    return moment(view_value, moment_format).format();
                }
            });

            ngModelController.$formatters.push(function(model_value) {
                if (model_value === '') {
                    return '';
                } else {
                    return moment(model_value).format(moment_format);
                }
            });

            $timeout(function() {
                $('.date').datepicker({
                    autoclose: true,
                    clearBtn: true,
                    orientation: 'bottom',
                    language: attrs.language,
                    format: datepicker_format
                });
                $('.date:focus').datepicker('show');
            });
        }
    };
}]);
